@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -97,13 +97,13 @@ public:
 
     switch (opt.branching()) {
     case BRANCH_NONE:
-      branch(*this, le, INT_VAR_NONE, INT_VAL_MIN);
+      branch(*this, le, INT_VAR_NONE(), INT_VAL_MIN());
       break;
     case BRANCH_INVERSE:
-      branch(*this, le.slice(le.size()-1,-1), INT_VAR_NONE, INT_VAL_MIN);
+      branch(*this, le.slice(le.size()-1,-1), INT_VAR_NONE(), INT_VAL_MIN());
       break;
     case BRANCH_SIZE:
-      branch(*this, le, INT_VAR_SIZE_MIN, INT_VAL_MIN);
+      branch(*this, le, INT_VAR_SIZE_MIN(), INT_VAL_MIN());
       break;
     }
   }
