@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2010
  *
  *  Last modified:
- *     $Date: 2011-09-19 22:02:26 +1000 (Mon, 19 Sep 2011) $ by $Author: schulte $
- *     $Revision: 12400 $
+ *     $Date: 2012-10-02 15:49:50 +0200 (Tue, 02 Oct 2012) $ by $Author: schulte $
+ *     $Revision: 13123 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -164,23 +164,50 @@ public:
     linear(*this, l, IRT_EQ, maxCredit);
     linear(*this, q, IRT_EQ, numberOfCourses);
 
-    if (opt.branching() == BRANCHING_NAIVE) {
-      branch(*this, x, INT_VAR_SIZE_MIN, INT_VAL_MIN);
-    } else {
-      Int::Branch::BySizeMin varsel(*this, VarBranchOptions::def);
-      ViewArray<Int::IntView> xv(*this, IntVarArgs(x));
-      if (opt.branching() == BRANCHING_LOAD) {
-        ValBestLoad<true> valsel(*this, ValBranchOptions::def);
-        ViewValBrancher<Int::Branch::BySizeMin, ValBestLoad<true> >
-          ::post(*this,xv,varsel,valsel);
-      } else { 
-        ValBestLoad<false> valsel(*this, ValBranchOptions::def);
-        ViewValBrancher<Int::Branch::BySizeMin, ValBestLoad<false> >
-          ::post(*this,xv,varsel,valsel);
-      }
+    switch (opt.branching()) {
+    case BRANCHING_NAIVE:
+      branch(*this, x, INT_VAR_SIZE_MIN(), INT_VAL_MIN());
+      break;
+    case BRANCHING_LOAD:
+      branch(*this, x, INT_VAR_SIZE_MIN(), INT_VAL(&load));
+      break;
+    case BRANCHING_LOAD_REV:
+      branch(*this, x, INT_VAR_SIZE_MIN(), INT_VAL(&load_rev));
+      break;
     }
   }
-    
+  /// Value selection function for load branching
+  static int load(const Space& home, IntVar x, int) {
+    const BACP& b = static_cast<const BACP&>(home);
+    IntVarValues values(x);
+    int val = -1;
+    int best = Int::Limits::max+1;
+    while (values()) {
+      if (b.l[values.val()].min() < best) {
+        val  = values.val();
+        best = b.l[val].min();
+      }
+      ++values;
+    }
+    assert(val != -1);
+    return val;
+  }
+  /// Value selection function for reverse load branching
+  static int load_rev(const Space& home, IntVar x, int) {
+    const BACP& b = static_cast<const BACP&>(home);
+    IntVarValues values(x);
+    int val = -1;
+    int best = Int::Limits::min-1;
+    while (values()) {
+      if (b.l[values.val()].min() > best) {
+        val  = values.val();
+        best = b.l[val].min();
+      }
+      ++values;
+    }
+    assert(val != -1);
+    return val;
+  }
   /// Constructor for copying \a bacp
   BACP(bool share, BACP& bacp) : MinimizeScript(share,bacp),
     curr(bacp.curr) {
@@ -216,46 +243,6 @@ public:
     os << std::endl;
   }
 
-  /** \brief Custom value selection class for a view-value branching.
-   *
-   * The value choosen is the value with the minimum load if the
-   * parameter \a minimize is true, otherwize it chooses the value for
-   * maximum load.
-   */
-  template <bool minimize>
-  class ValBestLoad : public ValSelBase<Int::IntView,int> {
-  public:
-    /// Default constructor
-    ValBestLoad(void) {}
-
-    /// Constructor for initialization
-    ValBestLoad(Space& home, const ValBranchOptions& vbo)
-      : ValSelBase<Int::IntView,int>(home,vbo) {}
-
-    /// Return minimum value of view \a x
-    int val(Space& home, Int::IntView x) const {
-      BACP& b = static_cast<BACP&>(home);
-      Int::ViewValues<Int::IntView> values(x);
-      int val = -1;
-      int best = minimize ? Int::Limits::max+1 : Int::Limits::min-1;
-      while (values()) {
-        if (minimize 
-            ? b.l[values.val()].min() < best
-            : b.l[values.val()].min() > best) {
-          val  = values.val();
-          best = b.l[val].min();
-        }
-        ++values;
-      }
-      assert(val != -1);
-      return val;
-    }
-
-    /// Tell \f$x=n\f$ (\a a = 0) or \f$x\neq n\f$ (\a a = 1)
-    ModEvent tell(Space& home, unsigned int a, Int::IntView x, int n) {
-      return (a == 0) ? x.eq(home,n) : x.gr(home,n);
-    }
-  };
 };
 
 /** \brief Main-function
