@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -130,7 +130,7 @@ public:
     }
     rel(*this, flight[noOfFlights-2] || flight[noOfFlights-1]);
 
-    branch(*this, flight, SET_VAR_NONE, SET_VAL_MIN_INC);
+    branch(*this, flight, SET_VAR_NONE(), SET_VAL_MIN_INC());
   }
 
   /// Print solution
