@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -105,7 +105,7 @@ public:
             cardinality(x[j] & cx[i]) +
             cardinality(x[i] & cx[j]) >= opt.distance());
 
-    branch(*this, x, SET_VAR_NONE, SET_VAL_MIN_INC);
+    branch(*this, x, SET_VAR_NONE(), SET_VAL_MIN_INC());
   }
 
   /// Print solution
