@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -100,7 +100,7 @@ public:
       rel(*this, v[*e1], BOT_AND, v[*e2], 0);
     }
     linear(*this, v, IRT_EQ, k);
-    branch(*this, v, INT_VAR_NONE, INT_VAL_MIN);
+    branch(*this, v, INT_VAR_NONE(), INT_VAL_MIN());
   }
 
   /// Constructor for cloning \a s
