@@ -9,8 +9,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -86,7 +86,7 @@ public:
       break;
     }
     linear(*this, IntArgs::create(n,-1,1), s, IRT_EQ, 0);
-    branch(*this, s, INT_VAR_NONE, INT_VAL_MAX);
+    branch(*this, s, INT_VAR_NONE(), INT_VAL_MAX());
   }
 
   /// Constructor for cloning \a e
