@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -94,7 +94,7 @@ public:
     rel(*this, m(0,0), IRT_GR, m(0,n-1));
     rel(*this, m(0,0), IRT_GR, m(n-1,0));
 
-    branch(*this, x, INT_VAR_SIZE_MIN, INT_VAL_SPLIT_MIN);
+    branch(*this, x, INT_VAR_SIZE_MIN(), INT_VAL_SPLIT_MIN());
   }
 
   /// Constructor for cloning \a s
