@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -125,7 +125,7 @@ public:
       rel(*this, ry1, IRT_GQ, ry2);
     }
 
-    branch(*this, z, INT_VAR_SIZE_MIN, INT_VAL_SPLIT_MIN);
+    branch(*this, z, INT_VAR_SIZE_MIN(), INT_VAL_SPLIT_MIN());
   }
 
   /// Constructor for cloning \a s
