@@ -9,8 +9,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2011-07-13 22:17:55 +1000 (Wed, 13 Jul 2011) $ by $Author: tack $
- *     $Revision: 12188 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -268,8 +268,8 @@ public:
       GECODE_NEVER;
     }
 
-    branch(*this, x, INT_VAR_MIN_MIN, INT_VAL_MIN);
-    branch(*this, y, INT_VAR_MIN_MIN, INT_VAL_MIN);
+    branch(*this, x, INT_VAR_MIN_MIN(), INT_VAL_MIN());
+    branch(*this, y, INT_VAR_MIN_MIN(), INT_VAL_MIN());
   }
 
   /// Constructor for cloning \a s
