@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2010-10-07 20:52:01 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11473 $
+ *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13061 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -113,10 +113,10 @@ public:
     rel(*this, pos[0] < pos[1]);
 
     if (opt.branching() == BRANCH_NONE) {
-      branch(*this, pos, INT_VAR_NONE, INT_VAL_MIN);
+      branch(*this, pos, INT_VAR_NONE(), INT_VAL_MIN());
     } else {
-      branch(*this, pos, tiebreak(INT_VAR_DEGREE_MAX,INT_VAR_SIZE_MIN),
-             INT_VAL_MIN);
+      branch(*this, pos, tiebreak(INT_VAR_DEGREE_MAX(),INT_VAR_SIZE_MIN()),
+             INT_VAL_MIN());
     }
   }
 
