@@ -7,8 +7,8 @@
  *     Christian Schulte, 2010
  *
  *  Last modified:
- *     $Date: 2010-10-07 08:20:35 +1100 (Thu, 07 Oct 2010) $ by $Author: schulte $
- *     $Revision: 11468 $
+ *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13068 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,7 +50,7 @@ namespace Gecode {
     if (b.size() != s.size())
       throw ArgumentSizeMismatch("Int::binpacking");      
     for (int i=s.size(); i--; )
-      Limits::positive(s[i],"Int::binpacking");
+      Limits::nonnegative(s[i],"Int::binpacking");
     if (home.failed()) return;
 
     ViewArray<OffsetView> lv(home,l.size());
