@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-09 05:10:29 +1000 (Wed, 09 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2013-02-20 17:42:40 +0100 (Wed, 20 Feb 2013) $ by $Author: schulte $
+ *     $Revision: 13341 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -49,7 +49,7 @@ namespace Gecode {
   template<class T>
   forceinline
   BAB<T>::BAB(T* s, const Search::Options& o)
-    : e(Search::bab(s,sizeof(T),o)) {}
+    : EngineBase(Search::bab(s,sizeof(T),o)) {}
 
   template<class T>
   forceinline T*
@@ -69,12 +69,6 @@ namespace Gecode {
     return e->stopped();
   }
 
-  template<class T>
-  forceinline
-  BAB<T>::~BAB(void) {
-    delete e;
-  }
-
   template<class T>
   T*
   bab(T* s, const Search::Options& o) {
